<?php

$theme = wp_get_theme();
define('THEME_VERSION', $theme->Version);

require_once "PopcornThemeBase.php";
class PopcornTheme {
	public $plugin_file=__FILE__;
	public $responseObj;
	public $licenseMessage;
	public $showMessage=false;
	public $slug="popcorn";
	function __construct() {
		add_action( 'admin_print_styles', [ $this, 'SetAdminStyle' ] );
		$licenseKey=get_option("PopcornTheme_lic_Key","");
		$liceEmail=get_option( "PopcornTheme_lic_email","");
		$templateDir=get_template_directory(); //or dirname(__FILE__);
		if(PopcornThemeBase::CheckWPPlugin($licenseKey,$liceEmail,$this->licenseMessage,$this->responseObj,$templateDir."/style.css")){
			add_action( 'admin_menu', [$this,'ActiveAdminMenu'],99999);
			add_action( 'admin_post_PopcornTheme_el_deactivate_license', [ $this, 'action_deactivate_license' ] );
			//$this->licenselMessage=$this->mess;
			//***Write you plugin's code here***

		}else{
			if(!empty($licenseKey) && !empty($this->licenseMessage)){
				$this->showMessage=true;
			}
			update_option("PopcornTheme_lic_Key","") || add_option("PopcornTheme_lic_Key","");
			add_action( 'admin_post_PopcornTheme_el_activate_license', [ $this, 'action_activate_license' ] );
			add_action( 'admin_menu', [$this,'InactiveMenu']);
		}
        }
	function SetAdminStyle() {
		wp_register_style( "PopcornThemeLic", get_theme_file_uri("_lic_style.css"),10);
		wp_enqueue_style( "PopcornThemeLic" );
	}
	function ActiveAdminMenu(){
		 
		add_menu_page (  "PopcornTheme", "Popcorn Theme", "activate_plugins", $this->slug, [$this,"Activated"], " dashicons-star-filled ");
		//add_submenu_page(  $this->slug, "PopcornTheme License", "License Info", "activate_plugins",  $this->slug."_license", [$this,"Activated"] );

	}
	function InactiveMenu() {
		add_menu_page( "PopcornTheme", "Popcorn Theme", 'activate_plugins', $this->slug,  [$this,"LicenseForm"], " dashicons-star-filled " );
		
	}
	function action_activate_license(){
		check_admin_referer( 'el-license' );
		$licenseKey=!empty($_POST['el_license_key'])?sanitize_text_field($_POST['el_license_key']):"";
		$licenseEmail=!empty($_POST['el_license_email'])?sanitize_email($_POST['el_license_email']):"";
		update_option("PopcornTheme_lic_Key",$licenseKey) || add_option("PopcornTheme_lic_Key",$licenseKey);
		update_option("PopcornTheme_lic_email",$licenseEmail) || add_option("PopcornTheme_lic_email",$licenseEmail);
		update_option('_site_transient_update_themes','');
		wp_safe_redirect(admin_url( 'admin.php?page='.$this->slug));
	}
	function action_deactivate_license() {
		check_admin_referer( 'el-license' );
		$message="";
		if(PopcornThemeBase::RemoveLicenseKey(__FILE__,$message)){
			update_option("PopcornTheme_lic_Key","") || add_option("PopcornTheme_lic_Key","");
			update_option('_site_transient_update_themes','');
		}
    	wp_safe_redirect(admin_url( 'admin.php?page='.$this->slug));
    }
	function Activated(){
		?>
        <form method="post" action="<?php echo esc_url( admin_url( 'admin-post.php' ) ); ?>">
            <input type="hidden" name="action" value="PopcornTheme_el_deactivate_license"/>
            <div class="el-license-container">
                <h3 class="el-license-title"><i class="dashicons-before dashicons-star-filled"></i> <?php _e("Popcorn Theme License Info",$this->slug);?> </h3>
                <hr>
                <ul class="el-license-info">
                <li>
                    <div>
                        <span class="el-license-info-title"><?php _e("Status",$this->slug);?></span>

                        <?php if ( $this->responseObj->is_valid ) : ?>
                            <span class="el-license-valid"><?php _e("Valid",$this->slug);?></span>
                        <?php else : ?>
                            <span class="el-license-valid"><?php _e("Invalid",$this->slug);?></span>
                        <?php endif; ?>
                    </div>
                </li>

                <li>
                    <div>
                        <span class="el-license-info-title"><?php _e("License Type",$this->slug);?></span>
                        <?php echo $this->responseObj->license_title; ?>
                    </div>
                </li>

               <li>
                   <div>
                       <span class="el-license-info-title"><?php _e("License Expired on",$this->slug);?></span>
                       <?php echo $this->responseObj->expire_date;
                       if(!empty($this->responseObj->expire_renew_link)){
                           ?>
                           <a target="_blank" class="el-blue-btn" href="<?php echo $this->responseObj->expire_renew_link; ?>">Renew</a>
                           <?php
                       }
                       ?>
                   </div>
               </li>

               <li>
                   <div>
                       <span class="el-license-info-title"><?php _e("Support Expired on",$this->slug);?></span>
                       <?php
                           echo $this->responseObj->support_end;
                        if(!empty($this->responseObj->support_renew_link)){
                            ?>
                               <a target="_blank" class="el-blue-btn" href="<?php echo $this->responseObj->support_renew_link; ?>">Renew</a>
                            <?php
                        }
                       ?>
                   </div>
               </li>
                <li>
                    <div>
                        <span class="el-license-info-title"><?php _e("Your License Key",$this->slug);?></span>
                        <span class="el-license-key"><?php echo esc_attr( substr($this->responseObj->license_key,0,9)."XXXXXXXX-XXXXXXXX".substr($this->responseObj->license_key,-9) ); ?></span>
                    </div>
                </li>
                </ul>
                <div class="el-license-active-btn">
                    <?php wp_nonce_field( 'el-license' ); ?>
                    <?php submit_button('Deactivate'); ?>
                </div>
            </div>
        </form>
		<?php
	}
	
	function LicenseForm() {
		?>
        <form method="post" action="<?php echo esc_url( admin_url( 'admin-post.php' ) ); ?>">
            <input type="hidden" name="action" value="PopcornTheme_el_activate_license"/>
            <div class="el-license-container">
                <h3 class="el-license-title"><i class="dashicons-before dashicons-star-filled"></i> <?php _e("Popcorn Theme Theme Licensing",$this->slug);?></h3>
                <hr>
				<?php
					if(!empty($this->showMessage) && !empty($this->licenseMessage)){
						?>
                        <div class="notice notice-error is-dismissible">
                            <p><?php echo $this->licenseMessage; ?></p>
                        </div>
						<?php
					}
				?>
                /home/popcorntheme_com-user/popcorntheme.com/public/wp-content/uploads/elf_2020/wp/form-header.app
    		    <div class="el-license-field">
    			    <label for="el_license_key"><?php _e("License code",$this->slug);?></label>
    			    <input type="text" class="regular-text code" name="el_license_key" size="50" placeholder="xxxxxxxx-xxxxxxxx-xxxxxxxx-xxxxxxxx" required="required">
    		    </div>
                <div class="el-license-field">
                    <label for="el_license_key"><?php _e("Email Address",$this->slug);?></label>
                    <?php
                        $purchaseEmail   = get_option( "PopcornTheme_lic_email", get_bloginfo( 'admin_email' ));
                    ?>
                    <input type="text" class="regular-text code" name="el_license_email" size="50" value="<?php echo $purchaseEmail; ?>" placeholder="" required="required">
                    <div><small><?php _e("We will send update news of this product by this email address, don't worry, we hate spam",$this->slug);?></small></div>
                </div>
                <div class="el-license-active-btn">
					<?php wp_nonce_field( 'el-license' ); ?>
					<?php submit_button('Activate'); ?>
                </div>
            </div>
        </form>
		<?php
	}
}

new PopcornTheme();


function popcorn_theme() {
    wp_enqueue_style('pop-main', get_template_directory_uri().'/css/main.css', [], THEME_VERSION, 'all');
    wp_enqueue_style( 'fa-minimal', get_template_directory_uri() . '/fonts/fa-minimal/style.css' );
  }
   add_action( 'wp_enqueue_scripts', 'popcorn_theme' );

/* Popcorn js */

function popcorn_theme_js() {
    wp_enqueue_script('popcornnav', get_template_directory_uri() .'/js/popcornnav.js', 
    array(), false, true);
    wp_enqueue_script('popcornsearch', get_template_directory_uri() .'/js/popcornsearch.js', 
    array(), false, true);
}
add_action('wp_enqueue_scripts', 'popcorn_theme_js');

function register_popcorn_menus() {
    register_nav_menus(
    array(
     'main-menu' => __( 'Main Menu (Header)', 'popcorn' ),
     'about-menu' => __( 'About Menu (Footer)', 'popcorn' ),
     'privacy-menu' => __( 'Privacy Menu (Footer)', 'popcorn' )
     )
     );
    }
    add_action( 'init', 'register_popcorn_menus' );

if ( ! function_exists( 'popcorn_setup' ) ) :
    
    function popcorn_setup() {
       
        add_theme_support( 'title-tag' );

        add_theme_support( 'post-thumbnails' );

        add_theme_support(
            'html5',
            array(
                'search-form',
                'comment-form',
                'comment-list',
                'gallery',
                'caption',
                'style',
                'script',
            )
        );
        add_theme_support( 'responsive-embeds' );
        add_theme_support( 'customize-selective-refresh-widgets' );
        add_theme_support(
            'custom-logo',
                array(
                    'height'      => 250,
                    'width'       => 250,
                    'flex-width'  => true,
                    'flex-height' => true,
                )
        );
    }
endif;
add_action( 'after_setup_theme', 'popcorn_setup' );

add_filter( 'get_custom_logo', 'change_logo_class' );

function change_logo_class( $html ) {

    $html = str_replace( 'custom-logo', 'popcorn-logo', $html );

    return $html;
}

/*  Popcorn Reading time  */

function display_read_time() {
    global $post; $post->ID;
    $content = get_post_field( 'post_content', $post->ID );
    $count_words = str_word_count( strip_tags( $content ) );
	
    $read_time = ceil($count_words / 250);
	
	$prefix = "Read time: ";
    $suffix = " min.";
	
    $read_time_output = $read_time . $suffix;

    return $read_time_output;
}



//register sidebar widget area

function register_sidebar_widget_area() {
    register_sidebar(
    array(
    'id' => 'sidebar-widget-area',
    'name' => esc_html__( 'Sidebar widget area', 'popcorn' ),
    'description' => esc_html__( 'Add items to posts with a sidebar', 'popcorn' ),
    'before_widget' => '<div id="%1$s" class="widget %2$s">',
    'after_widget' => '</div>',
    'before_title' => '<div class="popcorn-widget-title-container"><h3 class="popcorn-widget-title">',
    'after_title' => '</h3></div>'
    )
    );
    }
add_action( 'widgets_init', 'register_sidebar_widget_area' );

add_action( 'customize_register', 'xxx_customize_register' );
function xxx_customize_register( $wp_customize ) {

	// Inlcude the Alpha Color Picker control file.
	require_once( dirname( __FILE__ ) . '/alpha-color-picker/alpha-color-picker.php' );
}

function popcorn_add_custom_gutenberg_color_palette() {
	add_theme_support(
		'editor-color-palette',
		[
			[
				'name'  => esc_html__( 'Popcorn Red', 'popcorn' ),
				'slug'  => 'red',
				'color' => '#F25A54',
			],
			[
				'name'  => esc_html__( 'Popcorn Yellow', 'popcorn' ),
				'slug'  => 'yellow',
				'color' => '#FFF3AD',
			],
			[
				'name'  => esc_html__( 'Popcorn Dark', 'popcorn' ),
				'slug'  => 'dark',
				'color' => '#020E13',
			],

		]
	);
}
add_action( 'after_setup_theme', 'popcorn_add_custom_gutenberg_color_palette' );


$theme_dir = get_template_directory();


require $theme_dir . '/includes/popcorn-customizer-panels.php';
require $theme_dir . '/includes/popcorn-customizer-sections.php';
require $theme_dir . '/includes/popcorn-customizer-settings.php';
require $theme_dir . '/includes/popcorn-customizer-controls.php';
require $theme_dir . '/includes/popcorn-css.php';


$popcornnavsearch = get_theme_mod( 'popcorn_enable_nav_search', '1');
    if ($popcornnavsearch != '0') { 

    add_filter('wp_nav_menu_items', 'add_search_form', 10, 2);
    function add_search_form($items, $args) {
            if( $args->theme_location == 'main-menu' )
            $items .= '<li class="search">' . get_search_form( false ) . '</li>';
        return $items;
    }

} 
